<?php
/**
 * umctheme3 functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package umctheme3
 */

if ( ! defined( '_S_VERSION' ) ) {
	// Replace the version number of the theme on each release.
	define( '_S_VERSION', '3.0' );
}

if ( ! function_exists( 'umctheme3_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function umctheme3_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on umctheme3, use a find and replace
		 * to change 'umctheme3' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'umctheme3', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		add_theme_support( 'align-wide' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// Enables the Excerpt meta box in Page edit screen.
		add_post_type_support( 'page', 'excerpt' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus(
			array(
				// top_menu & main_menu ONLY USED ON UTAH.EDU HOMEPAGE
				// 'top_menu' => esc_html__( 'Top Menu', 'umctheme3' ),
				// 'main_menu' => esc_html__( 'Main Menu', 'umctheme3' ),
				'sidenav_menu1' => esc_html__( 'Side Nav Menu 1', 'umctheme3' ),
				'sidenav_menu2' => esc_html__( 'Side Nav Menu 2', 'umctheme3' ),
				'sidenav_menu3' => esc_html__( 'Side Nav Menu 3', 'umctheme3' ),
				'footer_menu1' => esc_html__( 'Footer Menu 1', 'umctheme3' ),
				'footer_menu2' => esc_html__( 'Footer Menu 2', 'umctheme3' ),
				'footer_menu3' => esc_html__( 'Footer Menu 3', 'umctheme3' ),
				'footer_menu4' => esc_html__( 'Footer Menu 4', 'umctheme3' ),
			)
		);

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
				'style',
				'script',
			)
		);

		// Set up the WordPress core custom background feature.
		add_theme_support(
			'custom-background',
			apply_filters(
				'umctheme3_custom_background_args',
				array(
					'default-color' => 'ffffff',
					'default-image' => '',
				)
			)
		);

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support(
			'custom-logo',
			array(
				'height'      => 250,
				'width'       => 250,
				'flex-width'  => true,
				'flex-height' => true,
			)
		);
	}
endif;
add_action( 'after_setup_theme', 'umctheme3_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function umctheme3_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'umctheme3_content_width', 640 );
}
add_action( 'after_setup_theme', 'umctheme3_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function umctheme3_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Sidebar', 'umctheme3' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Add widgets here.', 'umctheme3' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);
}
add_action( 'widgets_init', 'umctheme3_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function umctheme3_scripts() {

	wp_enqueue_style( 'aos-style', get_template_directory_uri() . '/css/vendor/aos/aos.css', array(), time(), 'all' );
	wp_enqueue_style( 'umctheme3-custom', get_template_directory_uri() . '/css/main.css', array(), time(), 'all' );
	wp_enqueue_style( 'umctheme3-style', get_stylesheet_uri(), array(), _S_VERSION );
	wp_style_add_data( 'umctheme3-style', 'rtl', 'replace' );

	wp_enqueue_script( 'fa-js', get_template_directory_uri() . '/js/vendor/fontawesome/all.js', array(), '5.15.4', false );
	wp_enqueue_script( 'aos', get_template_directory_uri() . '/js/vendor/aos/aos.js', array(), '1.0', false );
	wp_enqueue_script( 'umctheme3-navigation', get_template_directory_uri() . '/js/navigation.js', array(), _S_VERSION, true );
	wp_enqueue_script( 'umctheme3-ga-event', get_template_directory_uri() . '/js/ga_event.js', array(), _S_VERSION, true );
	wp_enqueue_script( 'umctheme3-app', get_template_directory_uri() . '/js/app.js', array('jquery'), _S_VERSION, true );

	wp_localize_script('umctheme3-app', 'wp_urls', array( 'siteurl' => get_option('siteurl') ));

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
		// REMOVE WEBSITE FROM COMMENTS FORM
		add_filter('comment_form_default_fields', 'unset_url_field');
		function unset_url_field($fields){
		    if(isset($fields['url']))
		       unset($fields['url']);
		       return $fields;
		}
	}
}
add_action( 'wp_enqueue_scripts', 'umctheme3_scripts' );

// ADD BTN CLASS TO COMMENT FORM
function umcetheme3_comment_form_defaults( $defaults ) {
    $defaults[ 'class_submit' ] = 'btn';
    return $defaults;
};
add_filter( 'comment_form_defaults', 'umcetheme3_comment_form_defaults' );
// CUSTOM COOKIE MESSAGE FOR COMMENT FORM
add_filter( 'comment_form_default_fields', function( $fields ) {
    $commenter = wp_get_current_commenter();
    $consent   = empty( $commenter['comment_author_email'] ) ? '' : ' checked="checked"';
    $fields['cookies'] = '<p class="comment-form-cookies-consent"><input id="wp-comment-cookies-consent" name="wp-comment-cookies-consent" type="checkbox" value="yes"' . $consent . ' />' . '<label for="wp-comment-cookies-consent"> Save my name and email in this browser for the next time I comment.</label></p>';
    return $fields;
}, 20 );

// WRAP EMBEDS WITH 16BY9 DIV
function wrap_embed_with_div( $html ) {
    return '<div class="embed-responsive embed-responsive-16by9">' . $html . '</div>';
}
add_filter( 'embed_oembed_html', 'wrap_embed_with_div', 10, 3 );

function umcetheme3_custom_fa_attribute($tag, $handle) {
	if ( 'fontawesome' !== $handle )
	return $tag;
	return str_replace( ' src', ' data-search-pseudo-elements defer src', $tag );
}
add_filter('script_loader_tag', 'umcetheme3_custom_fa_attribute', 10, 2);

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Breadcrumbs
 */
require get_template_directory() . '/inc/breadcrumbs.php';

/**
 * Metaboxes
 */
require get_template_directory() . '/inc/metaboxes.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

/**
 * Plugin activation
 */
require get_template_directory() . '/inc/tgm-plugin-activation.php';

/**
 * Display Category and Tag Ids in list view
 */
require get_template_directory() . '/inc/display-post-cat-ids.php';

/**
 * Add WYSIWYG enhancements
 */
//require get_template_directory() . '/inc/tinymce-styles.php';
